<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>Installering av MX-kodeker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Dette programmet kan installere lovlig begrensede kodeker som har avansert video- og lydfunksjonalitet.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt; De kan ikke uten videre distribueres i alle jurisdiksjoner. Undersøk om du lovlig kan ta dem i bruk.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Tar du juridisk ansvar for nedlastingen av disse kodekene?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Laster ned kodekfiler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Forkast alle endringer og avslutt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Begin codec download and installation</source>
        <translation>Begynn kodek-nedlasting og installasjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation>Om dette programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="105"/>
        <location filename="../mainwindow.cpp" line="112"/>
        <location filename="../mainwindow.cpp" line="120"/>
        <location filename="../mainwindow.cpp" line="128"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="153"/>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Utfører kommando …&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="131"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="146"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="164"/>
        <location filename="../mainwindow.cpp" line="193"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Cannot connect to the download site</source>
        <translation>Kan ikke koble til nedlastingssiden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <location filename="../mainwindow.cpp" line="132"/>
        <location filename="../mainwindow.cpp" line="147"/>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>Error downloading %1</source>
        <translation>Feil ved nedlasting av %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nedlasting fullført.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Installing downloaded files</source>
        <translation>Installerer nedlastede filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="194"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Fant ingen nedlastede *.deb-filer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Installerer …&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="220"/>
        <source>Error installing %1</source>
        <translation>Feil ved installasjon av %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Fix missing dependencies...</source>
        <translation>Fiks manglende avhengigheter …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Error running %1 command</source>
        <translation>Feil ved kjøring av kommandoen %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Installasjonen er fullført&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Finished</source>
        <translation>Fullført</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Kodekfilene er nå blitt lagret og installert uten feil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Installasjonen er fullført. Det har oppstått feil under installasjonen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>About MX Codecs</source>
        <translation>Om MX-kodeker</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>MX Codecs</source>
        <translation>MX-kodeker</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Enkel nedlasting av kodeker for MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>Klarte ikke å få eksklusiv lås</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Et annet pakkeinstalleringsprogram (som Synaptic eller apt-get) kjører allerede. Vennligst lukk det programmet først.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Du må kjøre dette programmet som root.</translation>
    </message>
</context>
</TS>